pecos.qeclib.generic
====================

.. automodule:: pecos.qeclib.generic



















.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   pecos.qeclib.generic.check
   pecos.qeclib.generic.check_1flag
